MockIO

Struct MockIO 

pub struct MockIO<const N: usize>(/* private fields */);
Mocked RegisterIO implementation.

Implemented as an array of N bytes, register writes and reads simply write to/from the internal array.

Implementations

Source

impl<const N: usize> MockIO<N>

pub fn new_zeroed() -> Self

Construct a new zeroed instance of the mocked register memory.

pub fn base_ptr(&self) -> *mut ()

Get the base register address of the instance (always 0).